# Vimeo Analytics.js Plugin

Automatically track Vimeo video player events as Segment events.

## Installation

The plugin is distributed as both an NPM package and as a direct export via a CDN. Please read more about installing Analytics.js Plugins here.

### CDN

Simply add the following script tag to the `head` of your site. `VimeoAnalytics` will be available as part of the global `window.analytics.plugins` object.

```html
<script src="https://cdn.jsdelivr.net/npm/@segment/vimeo-analytics.js-plugin@1.0.1/dist/vimeo.min.js"></script>
```
> The above url will download the minified version of the plugin. Don’t use this version during development! You will miss out on all the nice warnings for common mistakes! To access the unminified version, simply repalce `vimeo.min.js` with `vimeo.js`

### NPM

```bash
# latest stable
$ npm install @segment/vimeo-analytics.js-plugin
```

## Initializing

To initialize the plugin you will need to create a new instance of the `VimeoAnalytics` class and pass in the Vimeo.Player instance(s) running on your page as the first argument and an array of objects, each containing information about the video(s) that are accessible in the player, as the second argument. The metadata object for each video should conform to our [spec](https://segment.com/docs/spec/video/#content-event-object).

Please read more about the constructor function in the API documentation.

Next, you will need to start the plugin by calling it's `initialize` method.

```html
<iframe src="https://player.vimeo.com/video/76979871" width="640" height="360" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>

<script src="https://player.vimeo.com/api/player.js"></script>
<script>
    var iframe = document.querySelector('iframe');
    var player = new Vimeo.Player(iframe);
    var VimeoAnalytics = window.analytics.plugins.VimeoAnalytics
    var vimeoAnalytics = new VimeoAnalytics(player, [{
        sessionId: 'abcd-efgh-ijklm',
        // The `assetId` must be Vimeo video Id.
        assetId: '76979871',
        program: 'Planet Earth',
        title: 'Seasonal Forests',
        episode: 10,
        description: 'David Attenborough reveals the greatest woodlands on earth.',
        season: 1,
        genre: 'Documentary',
        publisher: 'BBC',
        fullEpisode: true,
        keywords: ['nature', 'forests', 'earth']
    }])
    vimeoAnalytics.initialize()
</script>
```

The plugin will now begin listening for the Vimeo Player lifecycle events and responding to them with Segment video events.

## API

### Constructor
```js
new VimeoAnalytics(player, metadata)
```

The `VimeoAnalyics` constructor takes as it's arguments the instance of the Vimeo Player you would like to track events for and an Array of metadata about the video(s) that are accessible in the player.

**Please ensure that the `assetId` you pass in with each [ContentEventObject](https://segment.com/docs/spec/video/#content-event-object) is the Vimeo Id for that video.**

#### Arguments
- `player` [VimeoPlayer](https://github.com/vimeo/player.js#create-a-player)
- `metadata` Array[[ContentEventObject](https://segment.com/docs/spec/video/#content-event-object)]


### Initialize
```js
vimeoAnalytics.initialize()
```

The `.initialize` method will bootstrap all the supported event listeners outlined below.

## Events

### Play
[Play](https://github.com/vimeo/player.js#play) events from the Vimeo Player will trigger [Video Content Started](https://segment.com/docs/spec/video/#video-content-started) and [Video Playback Started](https://segment.com/docs/spec/video/#video-playback-started) Segment events. If the video player was previously paused, the play event will instead trigger a [Video Playback Resumed](https://segment.com/docs/spec/video/#video-playback-resumed) event.

### Pause
[Pause](https://github.com/vimeo/player.js#pause) events from the Vimeo Player will trigger [Video Playback Paused](https://segment.com/docs/spec/video/#video-playback-paused) Segment events.

### Ended
[Ended](https://github.com/vimeo/player.js#ended) events from the Vimeo Player will trigger [Video Playback Completed](https://segment.com/docs/spec/video/#video-playback-completed) and [Video Content Completed](https://segment.com/docs/spec/video/#video-content-completed) Segment events.

### Time Update
[Time Update](https://github.com/vimeo/player.js#timeupdate) events from the Vimeo Player will trigger [Video Content Playing](https://segment.com/docs/spec/video/#video-playback-paused) "heartbeat" events every 10 seconds.

### Seek
[Seek](https://github.com/vimeo/player.js#seeked) events from the Vimeo Player will trigger [Video Playback Seek Started](https://segment.com/docs/spec/video/#video-playback-seek-started) and [Video Playback Seek Completed](https://segment.com/docs/spec/video/#video-playback-seek-completed) Segment events.

