'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _exportPlugin = require('../../../lib/exportPlugin');

var _exportPlugin2 = _interopRequireDefault(_exportPlugin);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var VimeoAnalytics = function () {
  function VimeoAnalytics(player, metadata) {
    _classCallCheck(this, VimeoAnalytics);

    this.player = player;
    this.metadata = metadata;
    this.mostRecentHeartbeat = 0;
    this.isPaused = false;
  }

  _createClass(VimeoAnalytics, [{
    key: 'initialize',
    value: function initialize() {
      var player = this.player;


      var events = {
        loaded: this.setCurrentVideo,
        play: this.trackPlay,
        pause: this.trackPause,
        ended: this.trackEnded,
        timeupdate: this.trackHeartbeat,
        seeked: this.trackSeek
      };

      for (event in events) {
        this.registerHandler(event, events[event]);
      }
    }

    // This is a helper function used to facilitate easier testing.

  }, {
    key: 'registerHandler',
    value: function registerHandler(event, handler) {
      var _this = this;

      this.player.on(event, function (data) {
        return handler.call(_this, data);
      });
    }
  }, {
    key: 'setCurrentVideo',
    value: function setCurrentVideo(_ref) {
      var videoId = _ref.id;
      var player = this.player,
          metadata = this.metadata;

      var currentVideoMetadata = metadata.find(function (m) {
        return m.assetId == videoId;
      });
      if (!currentVideoMetadata) {
        console.warn('Could not locate metadata for Vimeo video with id ' + videoId);
        this.currentVideoMetadata = {};
      } else {
        this.currentVideoMetadata = currentVideoMetadata;
      }
      this.videoId = videoId;
    }
  }, {
    key: 'trackPlay',
    value: function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(data) {
        var isPaused, currentVideoMetadata, props;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                isPaused = this.isPaused, currentVideoMetadata = this.currentVideoMetadata;
                _context.next = 3;
                return this.getPlayerProps(data);

              case 3:
                props = _context.sent;

                if (isPaused) {
                  window.analytics.track('Video Playback Resumed', props);
                  window.analytics.track('Video Content Started', Object.assign(currentVideoMetadata, props));
                  this.isPaused = false;
                } else {
                  window.analytics.track('Video Playback Started', props);
                  window.analytics.track('Video Content Started', Object.assign(currentVideoMetadata, props));
                }

              case 5:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function trackPlay(_x) {
        return _ref2.apply(this, arguments);
      }

      return trackPlay;
    }()
  }, {
    key: 'trackEnded',
    value: function () {
      var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(data) {
        var props;
        return regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.next = 2;
                return this.getPlayerProps(data);

              case 2:
                props = _context2.sent;

                window.analytics.track('Video Playback Completed', props);
                window.analytics.track('Video Content Completed', Object.assign(this.currentVideoMetadata, props));

              case 5:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function trackEnded(_x2) {
        return _ref3.apply(this, arguments);
      }

      return trackEnded;
    }()
  }, {
    key: 'trackHeartbeat',
    value: function () {
      var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(data) {
        var mostRecentHeartbeat, currentPosition, props;
        return regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                // Vimeo provides time updates every 250ms while Segment documents sending heartbeats every 10s.
                // Therefore, we need to do some math to ensure we are not sending 4 heartbeat events when we reach
                // 10 second intervals.
                mostRecentHeartbeat = this.mostRecentHeartbeat;
                currentPosition = Math.floor(data.seconds);

                if (!(currentPosition !== mostRecentHeartbeat && currentPosition - mostRecentHeartbeat >= 10)) {
                  _context3.next = 8;
                  break;
                }

                _context3.next = 5;
                return this.getPlayerProps(data);

              case 5:
                props = _context3.sent;

                window.analytics.track('Video Content Playing', Object.assign(props, this.currentVideoMetadata));
                this.mostRecentHeartbeat = currentPosition;

              case 8:
                this.mostRecentPosition = currentPosition;

              case 9:
              case 'end':
                return _context3.stop();
            }
          }
        }, _callee3, this);
      }));

      function trackHeartbeat(_x3) {
        return _ref4.apply(this, arguments);
      }

      return trackHeartbeat;
    }()
  }, {
    key: 'trackSeek',
    value: function () {
      var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(data) {
        var props;
        return regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                _context4.next = 2;
                return this.getPlayerProps(data);

              case 2:
                props = _context4.sent;

                window.analytics.track('Video Playback Seek Started', Object.assign({}, props, {
                  position: this.mostRecentPosition,
                  seekPosition: Math.round(data.seconds)
                }));
                window.analytics.track('Video Playback Seek Completed', props);

              case 5:
              case 'end':
                return _context4.stop();
            }
          }
        }, _callee4, this);
      }));

      function trackSeek(_x4) {
        return _ref5.apply(this, arguments);
      }

      return trackSeek;
    }()
  }, {
    key: 'trackPause',
    value: function () {
      var _ref6 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5(data) {
        var props;
        return regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) {
            switch (_context5.prev = _context5.next) {
              case 0:
                this.isPaused = true;
                _context5.next = 3;
                return this.getPlayerProps(data);

              case 3:
                props = _context5.sent;

                window.analytics.track('Video Playback Paused', props);

              case 5:
              case 'end':
                return _context5.stop();
            }
          }
        }, _callee5, this);
      }));

      function trackPause(_x5) {
        return _ref6.apply(this, arguments);
      }

      return trackPause;
    }()
  }, {
    key: 'getPlayerProps',
    value: function () {
      var _ref7 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6(data) {
        var player, currentVideoMetadata, videoId, volume;
        return regeneratorRuntime.wrap(function _callee6$(_context6) {
          while (1) {
            switch (_context6.prev = _context6.next) {
              case 0:
                player = this.player, currentVideoMetadata = this.currentVideoMetadata, videoId = this.videoId;
                _context6.next = 3;
                return player.getVolume();

              case 3:
                volume = _context6.sent;
                return _context6.abrupt('return', {
                  videoId: videoId,
                  sound: Math.round(volume * 100),
                  totalLength: Math.round(data.duration),
                  sessionId: currentVideoMetadata.sessionId,
                  position: Math.round(data.seconds),
                  videoPlayer: 'vimeo'
                });

              case 5:
              case 'end':
                return _context6.stop();
            }
          }
        }, _callee6, this);
      }));

      function getPlayerProps(_x6) {
        return _ref7.apply(this, arguments);
      }

      return getPlayerProps;
    }()
  }]);

  return VimeoAnalytics;
}();

exports.default = (0, _exportPlugin2.default)(VimeoAnalytics);
